# Migration from UJET Web SDK v1 to v2.0

The following updates need to be made when migrating from UJET Web SDK v1 to v2:

## Update URLs

First, update the host and loader URLs, like such

```
// v1
loader: https://websdk.ujet.co/v1/loader/loader.js
host: https://sfco.ujet.co/api/v2

// v2
loader: https://websdk.ujet.co/v2/loader.js
host: https://sfco.api.ujet.co
```

## Authentication

The authentication method should now return a promise that resolves with the JWT token.

## intialization:

```
// v1
UJET.initialize({
  // ...
})

// v2
new UJET({
  // ...
})
```

## options:

Here is the full list of options in v2.

```
companyId
tenant
lang
host
authenticate
user: {
  name
  email
},
logo
style
menuKey
ticketId
customData
disableAttachment
right
bottom
translation
launcher
```

### logo

```js
// v1
UJET.initialize({
  // ...
  logoUrl: 'https://example.com/logo.svg',
})

// v2
new UJET({
  // ...
  logo: 'https://example.com/logo.svg',
})
```

### position

```js
// v1
UJET.initialize({
  iconPosition: {
    right: 50,
    bottom: 50,
  }
})

// v2
new UJET({
  // widget position
  right: '50px',
  bottom: '150px',

  // launcher position
  launcher: {
    right: '50px',
    bottom: '50px',
  }
})
```

### language

```js
// v1
UJET.initialize({
  defaultLanguage: 'en',
})

// v2
new UJET({
  lang: 'en',
})
```

### theme

```js
// v1
UJET.initialize({
  theme: {
    stylesheets: [
      'https://example.com/font.css',
    ],
    color: '#FAD',
    font: 'MyFont, sans-serif'
  }
})

// v2
new UJET({
  // style in widget
  style: {
    links: [
      'https://example.com/font.css',
    ],
    '--primary-color': '#3498DB',
    '--primary-font': 'MyFont, sans-serif',
    '--primary-light-color': 'EAF5FD',
    '--link-color': '#3498DB',
  },

  // style for launcher
  launcher: {
    style: {
      '--background-color': '#3498DB',
      '--icon-color': '#FFFFFF',
      '--count-color': '#EE0000',
    }
  }
})
```

### no launcher

```js
// v1
UJET.initialize({
  hideLauncher: true,
})

// v2
new UJET({
  launcher: false,
})
```

### hide logo border

```js
// v1
UJET.initialize({
  hideLogoBorder: true,
})

// v2
new UJET({
  style: {
    '--logo-shadow': 'none',
  }
})
```
